@@ -2,7 +2,7 @@
   (:require [amazonica.core :as amz]
             [clojure.walk :as walk])
   (:import [com.amazonaws.services.ecs AmazonECSClient]
-           (com.amazonaws.services.ecs.model LogConfiguration)))
+           (com.amazonaws.services.ecs.model LogConfiguration LogDriver)))
 
 (amz/set-client AmazonECSClient *ns*)
 
@@ -10,6 +10,6 @@
   LogConfiguration
   (fn [value]
     (doto (LogConfiguration.)
-      (.setLogDriver (:log-driver value))
+      (.setLogDriver ^LogDriver (:log-driver value))
       (.setOptions (walk/stringify-keys (:options value))))))
 
