@@ -3,12 +3,12 @@
         [robert.hooke :only (add-hook)])
   (:import com.amazonaws.services.glacier.AmazonGlacierClient
            amazonica.TreeHash
-           [java.io BufferedInputStream FileInputStream]))
+           [java.io File BufferedInputStream FileInputStream]))
 
 (set-client AmazonGlacierClient *ns*)
 
 (defn- file-hash->map
-  [file]
+  [^File file]
   {:content-length (.length file)
    :checksum       (-> file
                        TreeHash/computeSHA256TreeHash
@@ -31,4 +31,4 @@
                   (file-hash->map file))]
     (apply func (mapcat identity mm))))
 
-(add-hook #'upload-archive #'tree-hash)
\ No newline at end of file
+(add-hook #'upload-archive #'tree-hash)
