@@ -8,13 +8,20 @@
               AWSCredentialsProviderChain
               DefaultAWSCredentialsProviderChain]
            com.amazonaws.internal.StaticCredentialsProvider
-           com.amazonaws.services.kinesis.AmazonKinesisClient
+           com.amazonaws.services.dynamodbv2.streamsadapter.AmazonDynamoDBStreamsAdapterClient
+           [com.amazonaws.regions
+            Region
+            Regions]
+           [com.amazonaws.services.kinesis
+            AmazonKinesisClient]
            [com.amazonaws.services.kinesis.model
             Record]
            [com.amazonaws.services.kinesis.clientlibrary.interfaces
+              IRecordProcessorCheckpointer]
+           [com.amazonaws.services.kinesis.clientlibrary.interfaces.v2
+              IRecordProcessorFactory
               IRecordProcessor
-              IRecordProcessorCheckpointer
-              IRecordProcessorFactory]
+              IShutdownNotificationAware]
            [com.amazonaws.services.kinesis.clientlibrary.exceptions
               InvalidStateException
               KinesisClientLibDependencyException
@@ -24,6 +31,7 @@
               InitialPositionInStream
               KinesisClientLibConfiguration
               Worker
+              Worker$Builder
               ShutdownReason]
            [com.amazonaws.services.kinesis.metrics.interfaces
             MetricsLevel]
@@ -67,10 +75,19 @@
           (f (:cred parsed) :stream-name stream :records data-byte))))))
 
 (defn unwrap
+  "Get the contents of the given buffer as a byte-array, decoding as
+  Nippy bytes if they appear to be Nippy encoded. If the ByteBuffer
+  does not appear to contain Nippy data, the bytes found will be
+  returned unchanged. This technique is inspired by ptaoussanis/faraday."
   [^java.nio.ByteBuffer byte-buffer]
-  (let [b (byte-array (.remaining byte-buffer))]
-    (.get byte-buffer b)
-    (nippy/thaw b)))
+  (let [byte-array (.array byte-buffer)
+        serialized? (#'nippy/try-parse-header byte-array)]
+    (if-not serialized?
+      byte-array ; No Nippy header => assume non-nippy binary data
+      (try ; Header match _may_ have been a fluke (though v. unlikely)
+        (nippy/thaw byte-array)
+        (catch Exception e
+          byte-array)))))
 
 (alter-var-root
   #'amazonica.aws.kinesis/get-shard-iterator
@@ -99,11 +116,13 @@
 
 (defn marshall
   [deserializer ^Record record]
-  {:sequence-number (.getSequenceNumber record)
-   :partition-key   (.getPartitionKey record)
-   :data            (deserializer (.getData record))})
+  {:approximate-arrival-timestamp (amz/marshall (.getApproximateArrivalTimestamp record))
+   :encryption-type               (.getEncryptionType record)
+   :sequence-number               (.getSequenceNumber record)
+   :partition-key                 (.getPartitionKey record)
+   :data                          (deserializer (.getData record))})
 
-(defn- mark-checkpoint [^IRecordProcessorCheckpointer checkpointer _]
+(defn- mark-checkpoint [^IRecordProcessorCheckpointer checkpointer]
   (try
     (.checkpoint checkpointer)
     true
@@ -116,25 +135,33 @@
       false)))
 
 (defn- processor-factory
-  [processor deserializer checkpoint next-check]
+  [processor deserializer checkpoint]
   (reify IRecordProcessorFactory
-    (createProcessor [this]
-      (reify IRecordProcessor
-        (initialize [this shard-id])
-        (shutdown [this checkpointer reason]
-          (if (or (= ShutdownReason/TERMINATE reason)
-                  (= "TERMINATE" reason))
-              (some (partial mark-checkpoint checkpointer) [1 2 3 4 5])))
-        (processRecords [this records checkpointer]
-          (if (or (processor (functor/fmap (partial marshall deserializer)
-                                           (vec (seq records))))
-                  (and checkpoint
-                       (> (System/currentTimeMillis) @next-check)))
-              (do (if checkpoint
-                      (reset! next-check
-                              (+' (System/currentTimeMillis)
-                                  (*' 1000 checkpoint))))
-                  (some (partial mark-checkpoint checkpointer) [1 2 3 4 5]))))))))
+    (createProcessor [_this]
+      (let [next-check (atom 0)]
+        (reify IRecordProcessor
+          (initialize [_this _initialization-input])
+          (shutdown [_this shutdown-input]
+            (let [reason (.getShutdownReason shutdown-input)
+                  checkpointer (.getCheckpointer shutdown-input)]
+              (when (or (= ShutdownReason/TERMINATE reason)
+                        (= "TERMINATE" reason))
+                (some (fn [_] (mark-checkpoint checkpointer)) (repeat 5 nil)))))
+          (processRecords [_this process-records-input]
+            (let [records (vec (seq (.getRecords process-records-input)))
+                  checkpointer (.getCheckpointer process-records-input)]
+              (when (or (processor (functor/fmap (partial marshall deserializer)
+                                                 records))
+                        (and checkpoint
+                             (> (System/currentTimeMillis) @next-check)))
+                (when checkpoint
+                  (reset! next-check
+                          (+' (System/currentTimeMillis)
+                              (*' 1000 checkpoint))))
+                (some (fn [_] (mark-checkpoint checkpointer)) (repeat 5 nil)))))
+          IShutdownNotificationAware
+          (shutdownRequested [_this checkpointer]
+            (some (fn [_] (mark-checkpoint checkpointer)) (repeat 5 nil))))))))
 
 (defn- kinesis-client-lib-configuration
   "Instantiate a KinesisClientLibConfiguration instance."
@@ -144,6 +171,7 @@
            worker-id
            endpoint
            dynamodb-endpoint
+           billing-mode
            initial-position-in-stream
            ^java.util.Date initial-position-in-stream-date
            failover-time-millis
@@ -166,19 +194,20 @@
            region-name
            initial-lease-table-read-capacity
            initial-lease-table-write-capacity]
-    :or {worker-id (str (UUID/randomUUID))
-         endpoint "kinesis.us-east-1.amazonaws.com"}}]
+    :or {worker-id (str (UUID/randomUUID))}}]
   (cond-> (KinesisClientLibConfiguration. (name app)
                                           (name stream)
                                           provider
                                           (name worker-id))
-
           endpoint
           (.withKinesisEndpoint endpoint)
 
           dynamodb-endpoint
           (.withDynamoDBEndpoint dynamodb-endpoint)
 
+          billing-mode
+          (.withBillingMode billing-mode)
+
           initial-position-in-stream
           (.withInitialPositionInStream
            (InitialPositionInStream/valueOf (name initial-position-in-stream)))
@@ -254,19 +283,35 @@
   "Instantiate a kinesis Worker."
   [& args]
   (let [opts (if (associative? (first args))
-                 (first args)
-                 (apply hash-map args))
-        {:keys [processor deserializer checkpoint credentials]
+               (first args)
+               (apply hash-map args))
+        {:keys [processor deserializer checkpoint credentials dynamodb-adaptor-client? ^String region-name ^String endpoint]
          :or   {checkpoint 60
-                deserializer unwrap}} opts
-        next-check (atom 0)
-        factory  (processor-factory processor deserializer checkpoint next-check)
-        creds    (amz/get-credentials credentials)
-        provider (if (instance? AWSCredentials creds)
-                     (StaticCredentialsProvider. creds)
-                     creds)
-        config   (kinesis-client-lib-configuration provider opts)]
-    [(Worker. factory config) (.getWorkerIdentifier config)]))
+                deserializer unwrap
+                endpoint "kinesis.us-east-1.amazonaws.com"}} opts
+        factory           (processor-factory processor deserializer checkpoint)
+        creds             (amz/get-credentials credentials)
+        provider          (if (instance? AWSCredentials creds)
+                            (StaticCredentialsProvider. creds)
+                            creds)
+        config            (kinesis-client-lib-configuration provider (assoc opts :endpoint endpoint))
+        worker-identifier (.getWorkerIdentifier config)]
+    [(-> (Worker$Builder.)
+         (.recordProcessorFactory ^IRecordProcessorFactory factory)
+         (.config ^KinesisClientLibConfiguration config)
+         (cond->
+          dynamodb-adaptor-client?
+           ;; this will result in some warnings at debug from the kinesis client lib as it will try to set the region/endpoint on this client. 
+           ;; These are safe to ignore as we pre-configure the correct values
+           (.kinesisClient
+            (doto (if provider
+                    (AmazonDynamoDBStreamsAdapterClient. ^AWSCredentialsProvider provider (.getKinesisClientConfiguration config))
+                    (AmazonDynamoDBStreamsAdapterClient. (.getKinesisClientConfiguration config)))
+              (cond->
+               region-name ^AmazonDynamoDBStreamsAdapterClient (.setRegion (Region/getRegion (Regions/fromName region-name))))
+              (cond->
+               endpoint ^AmazonDynamoDBStreamsAdapterClient (.setEndpoint endpoint)))))
+         (.build)) worker-identifier]))
 
 (defn worker!
   "Instantiate a new kinesis Worker and invoke its run method in a
