@@ -5,7 +5,7 @@
 
 (amz/set-client AWSLambdaClient *ns*)
 
-(defn byte-buffer-zip-file [function-name body]
+(defn byte-buffer-zip-file [function-name ^String body]
   (let [baos (java.io.ByteArrayOutputStream.)
         zos  (java.util.zip.ZipOutputStream. baos)]
     (.putNextEntry zos (java.util.zip.ZipEntry. (str function-name ".js")))
@@ -15,7 +15,7 @@
     (java.nio.ByteBuffer/wrap (.toByteArray baos))))
 
 (defn function-name [node-fn]
-  (-> (re-find #"exports\..+=" node-fn)
+  (-> ^String (re-find #"exports\..+=" node-fn)
       (.replaceFirst "exports." "")
       (.replaceFirst "=" "")
       .trim))
@@ -29,7 +29,7 @@
         attrs   (merge {:timeout 10
                         :memory-size 256
                         :mode "event"
-                        :runtime "nodejs"
+                        :runtime "nodejs6.10"
                         :description "uploaded via amazonica"} attrs)
         fn-name (or (:function-name attrs) (function-name (:function attrs)))
         attrs   (if (:function attrs)
@@ -43,4 +43,4 @@
     (func (dissoc attrs :function))))
 
 
-(add-hook #'create-function #'parse-function)
\ No newline at end of file
+(add-hook #'create-function #'parse-function)
