@@ -1,8 +1,10 @@
 (ns amazonica.aws.s3
-  (:use [amazonica.core :only (IMarshall coerce-value marshall register-coercions 
+  (:use [amazonica.core :only (IMarshall coerce-value marshall register-coercions
                                set-fields to-date kw->str)]
         [clojure.algo.generic.functor :only (fmap)])
-  (:import [com.amazonaws.services.s3
+  (:import java.util.Date
+           com.amazonaws.HttpMethod
+           [com.amazonaws.services.s3
               AmazonS3Client]
            [com.amazonaws.regions Region Regions]
            [com.amazonaws.services.s3.model
@@ -16,6 +18,7 @@
               EmailAddressGrantee
               Filter
               FilterRule
+              GeneratePresignedUrlRequest
               Grant
               Grantee
               GroupGrantee
@@ -23,9 +26,12 @@
               ObjectMetadata
               Owner
               Permission
+              NotificationConfiguration
               QueueConfiguration
               S3KeyFilter
               S3Object
+              SSEAlgorithm
+              SSECustomerKey
               TagSet
               TopicConfiguration]))
 
@@ -33,17 +39,15 @@
 
 (defn- notification-configuration-instance
   [value]
-  (let [ks (->> value keys (reduce str))]
+  (let [^String ks (->> value keys (reduce str))
+        ^"[Ljava.lang.String;" events (into-array (:events value))]
     (cond
       (.contains ks "queue")
-      (QueueConfiguration. (or (:queue-ARN value) (:queue value))
-                           (into-array (:events value)))
+      (QueueConfiguration. (or ^String (:queue-arn value) ^String (:queue-ARN value) ^String (:queue value)) events)
       (.contains ks "topic")
-      (TopicConfiguration. (or (:topic-ARN value) (:topic value))
-                           (into-array (:events value)))
+      (TopicConfiguration. (or ^String (:topic-arn value) ^String (:topic-ARN value) ^String (:topic value)) events)
       (.contains ks "function")
-      (LambdaConfiguration. (or (:function-ARN value) (:function value))
-                            (into-array (:events value))))))
+      (LambdaConfiguration. (or ^String (:function-arn value) ^String (:function-ARN value) ^String (:function value)) events))))
 
 (defn- as-bucket-notification-config
   [value]
@@ -73,7 +77,7 @@
     (.setFilterRules s3ft (map f value))
     fltr))
 
-(defn- set-account-owner [acl]
+(defn- set-account-owner [^AccessControlList acl]
   (let [s3ns (find-ns (symbol "amazonica.aws.s3"))
         sym  (symbol "get-s3account-owner")
         own  (ns-resolve s3ns sym)]
@@ -83,7 +87,7 @@
         (println "[WARN] Unable to set account owner for ACL: "
                  (.getMessage e))))))
 
-(defn- notification-config [obj]
+(defn- notification-config [^NotificationConfiguration obj]
   {:events (set (.getEvents obj))
    :filter (marshall (.getFilter obj))})
 
@@ -167,6 +171,7 @@
       (when-let [sse (:server-side-encryption col)]
         (.setServerSideEncryption om sse))
       (when-let [sse-kms-key-id (:server-side-encryption-aws-kms-key-id col)]
+        (.setHeader om "x-amz-server-side-encryption" "aws:kms")
         (.setHeader om "x-amz-server-side-encryption-aws-kms-key-id" sse-kms-key-id))
       (when-let [metadata (:user-metadata col)]
         (doseq [[k v] metadata]
@@ -202,6 +207,42 @@
   Filter
   (fn [value]
     (as-filter value))
+  GeneratePresignedUrlRequest
+  (fn [value]
+    (let [req (GeneratePresignedUrlRequest. (:bucket-name value) (:key value))]
+      (if-let [content-md5 (:content-md5 value)]
+        (.setContentMd5 req content-md5))
+      (if-let [content-type (:content-type value)]
+        (.setContentType req content-type))
+      (if-let [expiration (:expiration value)]
+        (.setExpiration req (coerce-value expiration Date)))
+      (if-let [kms-cmk-id (:kms-cmk-id value)]
+        (.setKmsCmkId req kms-cmk-id))
+      (if-let [method (:method value)]
+        (.setMethod req (coerce-value method HttpMethod)))
+      (if-let [response-headers (:response-headers value)]
+        (.setResponseHeaders req response-headers))
+      (if-let [sse-algorithm (:sse-algorithm value)]
+        (.setSSEAlgorithm req sse-algorithm))
+      (if-let [sse-customer-key (:sse-customer-key value)]
+        (.setSSECustomerKey
+          req
+          (coerce-value sse-customer-key SSECustomerKey)))
+      (if-let [sse-customer-key-algorithm (:sse-customer-key-algorithm value)]
+        (.setSSECustomerKeyAlgorithm
+          req
+          (coerce-value sse-customer-key-algorithm SSEAlgorithm)))
+      (if-let [version-id (:version-id value)]
+        (.setVersionId req version-id))
+      (if-let [zero-byte-content (:zero-byte-content value)]
+        (.setZeroByteContent req zero-byte-content))
+      (if-let [params (:request-parameters value)]
+        (doseq [k (keys params)]
+          (.addRequestParameter req (name k) (str (k params)))))
+      req))
+  SSECustomerKey
+  (fn [value]
+    (SSECustomerKey. value))
   Grant
   (fn [value]
     (Grant.
@@ -247,16 +288,14 @@
       (when-let [max-age-seconds (:max-age-seconds col)]
         (.setMaxAgeSeconds cors max-age-seconds))
       (when-let [allowed-headers (:allowed-headers col)]
-        (.setAllowedHeaders cors (into-array String allowed-headers)))
+        (.setAllowedHeaders cors ^"[Ljava.lang.String;" (into-array allowed-headers)))
       (when-let [allowed-origins (:allowed-origins col)]
-        (.setAllowedOrigins cors (into-array String allowed-origins)))
+        (.setAllowedOrigins cors ^"[Ljava.lang.String;" (into-array allowed-origins)))
       (when-let [exposed-headers (:exposed-headers col)]
-        (.setExposedHeaders cors (into-array String exposed-headers)))
+        (.setExposedHeaders cors ^"[Ljava.lang.String;" (into-array exposed-headers)))
       (when-let [allowed-methods (:allowed-methods col)]
-        (.setAllowedMethods cors
-                            (into-array CORSRule$AllowedMethods
-                    (fmap #(coerce-value % CORSRule$AllowedMethods)
-                          allowed-methods))))
+        (.setAllowedMethods cors ^"[Lcom.amazonaws.services.s3.model.CORSRule$AllowedMethods;"
+                            (into-array (fmap #(coerce-value % CORSRule$AllowedMethods) allowed-methods))))
       cors)))
 
 (amazonica.core/set-client AmazonS3Client *ns*)
