@@ -4,16 +4,27 @@
             [riemann.logging :as logging]
             riemann.time
             [riemann.test :as test]
+            [clojure.test :as clj-test]
+            [clojure.test.junit :refer [with-junit-output]]
             riemann.pubsub
             [cemerick.pomegranate :as pom]
             [clojure.java.io :as io]
-            [clojure.tools.logging :refer :all])
+            [clojure.tools.logging :refer [info error]])
+  (:import (clojure.lang DynamicClassLoader))
   (:gen-class :name riemann.bin))
 
 (def config-file
   "The configuration file loaded by the bin tool"
   (promise))
 
+(defn add-config-dir-to-classpath
+  [config-file]
+  (let [dir (-> config-file
+                io/file
+                .getCanonicalFile
+                .getParent)]
+    (pom/add-classpath dir)))
+
 (defn set-config-file!
   "Sets the config file used by Riemann. Adds the config file's enclosing
   directory to the classpath as well."
@@ -22,12 +33,7 @@
   (assert (deliver config-file file)
           (str "Config file already set to " (pr-str @config-file)
                "--can't change it to " (pr-str file)))
-  (let [dir (-> file
-                io/file
-                .getCanonicalPath
-                io/file
-                .getParent)]
-    (pom/add-classpath dir)))
+  (add-config-dir-to-classpath file))
 
 (def reload-lock (Object.))
 
@@ -48,16 +54,28 @@
         (error e "Couldn't reload:")
         e))))
 
+(defn ensure-dynamic-classloader
+  []
+  (let [thread (Thread/currentThread)
+        context-class-loader (.getContextClassLoader thread)
+        compiler-class-loader (.getClassLoader clojure.lang.Compiler)]
+    (when-not (instance? DynamicClassLoader context-class-loader)
+      (.setContextClassLoader
+        thread (DynamicClassLoader. (or context-class-loader
+                                        compiler-class-loader))))))
+
 (defn handle-signals
   "Sets up POSIX signal handlers."
   []
-  (if (not (.contains (. System getProperty "os.name") "Windows"))
+  (when-not (.contains (. System getProperty "os.name") "Windows")
     (sun.misc.Signal/handle
-      (sun.misc.Signal. "HUP")
-      (proxy [sun.misc.SignalHandler] []
-        (handle [sig]
-                (info "Caught SIGHUP, reloading")
-                (reload!))))))
+     (sun.misc.Signal. "HUP")
+     (proxy [sun.misc.SignalHandler] []
+       (handle [sig]
+         (info "Caught SIGHUP, reloading")
+         (ensure-dynamic-classloader)
+         (add-config-dir-to-classpath @config-file)
+         (reload!))))))
 
 (defn pom-version
   "Return version from Maven POM file."
@@ -77,10 +95,43 @@
   "Process identifier, such as it is on the JVM. :-/"
   []
   (let [name (-> (java.lang.management.ManagementFactory/getRuntimeMXBean)
-               (.getName))]
+                 (.getName))]
     (try
       (get (re-find #"^(\d+).*" name) 1)
-      (catch Exception e name))))
+      (catch Exception _ name))))
+
+(defn run-tests-with-format
+  "Run all tests matching `test-name-pattern`.
+  If the `test.output.format` property is set to `junit`, the test output will be
+  JUnit compatible."
+  [test-name-pattern]
+  (if (= (System/getProperty "test.output.format")
+         "junit")
+    (with-junit-output
+      (clj-test/run-all-tests test-name-pattern))
+    (clj-test/run-all-tests test-name-pattern)))
+
+(defn run-tests
+  "Run all tests matching `test-name-pattern`.
+  The test output will be saved in the `test.output.file` value if this property is set."
+  [test-name-pattern]
+  (if-let [file-path (System/getProperty "test.output.file")]
+    (with-open [w (java.io.FileWriter. file-path)]
+      (binding [clj-test/*test-out* w]
+        (run-tests-with-format test-name-pattern)))
+    (run-tests-with-format test-name-pattern)))
+
+(defn run-app!
+  "Start Riemann with the given setup function. The setup function is responsible
+  for executing code that you would normally put into your riemann.config file,
+  e.g. setting up streams."
+  [setup]
+  (info "PID" (pid))
+  (handle-signals)
+  (riemann.time/start!)
+  (setup)
+  (riemann.config/apply!)
+  nil)
 
 (defn -main
   "Start Riemann. Loads a configuration file from the first of its args."
@@ -90,15 +141,11 @@
    (-main "start" config))
   ([command config & [test-name]]
    (logging/init)
+   (ensure-dynamic-classloader)
    (case command
      "start" (try
-               (info "PID" (pid))
                (set-config-file! config)
-               (handle-signals)
-               (riemann.time/start!)
-               (riemann.config/include @config-file)
-               (riemann.config/apply!)
-               nil
+               (run-app! #(riemann.config/include @config-file))
                (catch Exception e
                  (error e "Couldn't start")))
 
@@ -106,13 +153,16 @@
               (test/with-test-env
                 (set-config-file! config)
                 (riemann.config/include @config-file)
-                (binding [test/*streams* (:streams @config/next-core)]
+                (reset! riemann.config/core @riemann.config/next-core)
+                (binding [test/*core* @config/core]
                   (let [test-name-pattern (if test-name (re-pattern test-name) #".*-test")
-                        results (clojure.test/run-all-tests test-name-pattern)]
+                        results (run-tests test-name-pattern)]
                     (if (and (zero? (:error results))
                              (zero? (:fail results)))
                       (System/exit 0)
-                      (System/exit 1))))))
+                      (System/exit 1)))))
+              (catch Exception e
+                (error e "Couldn't run tests")))
 
      "version" (try
                  (println (version))
