@@ -44,13 +44,19 @@
                             1000)) ;; default
     (when (.hasTtl e)         (.getTtl e))))
 
+(def blacklisted-attributes #{ "tags" "time" "ttl" "metric"})
+
+(defn blacklisted?
+  [^Proto$Attribute a]
+  (blacklisted-attributes (.getKey a)))
+
 (defn decode-pb-event
   [^Proto$Event e]
   (let [event (decode-pb-event-record e)]
     (if (< 0 (.getAttributesCount e))
       (into event (map (fn [^Proto$Attribute a]
                          [(keyword (.getKey a)) (.getValue a)])
-                       (.getAttributesList e)))
+                       (remove blacklisted? (.getAttributesList e))))
       event)))
 
 (defn ^Proto$Event encode-pb-event
@@ -72,7 +78,7 @@
                         (.setTime       event (long (:time e)))))
     (when (:ttl e)          (.setTtl          event (:ttl e)))
     (doseq [k (clojure.set/difference (set (keys e)) event-keys)]
-      (when-let [v (get e k)]
+      (when-some [v (get e k)]
         (let [a (Proto$Attribute/newBuilder)]
           (.setKey a (str (when (namespace k) (str (namespace k) \/)) (name k)))
           (.setValue a (str v))
