@@ -4,7 +4,9 @@
             [clojure.java.io :as io])
   (:import (java.net Socket Proxy Proxy$Type InetSocketAddress)
            (java.security KeyStore)
-           (org.apache.http.config RegistryBuilder Registry)
+           (javax.net.ssl KeyManager
+                          TrustManager)
+           (org.apache.http.config RegistryBuilder Registry SocketConfig)
            (org.apache.http.conn HttpClientConnectionManager)
            (org.apache.http.conn.ssl DefaultHostnameVerifier
                                      NoopHostnameVerifier
@@ -22,41 +24,48 @@
             IOReactorConfig
             AbstractMultiworkerIOReactor$DefaultThreadFactory
             DefaultConnectingIOReactor)
-           (org.apache.http.nio.conn NoopIOSessionStrategy)))
+           (org.apache.http.nio.conn NoopIOSessionStrategy)
+           (org.apache.http.nio.protocol HttpAsyncRequestExecutor)
+           (org.apache.http.impl.nio DefaultHttpClientIODispatch)
+           (org.apache.http.config ConnectionConfig)))
 
 (def ^:private insecure-context-verifier
-  {
-   :context (-> (SSLContexts/custom)
-                (.loadTrustMaterial nil (reify TrustStrategy
-                                          (isTrusted [_ _ _] true)))
-                (.build))
-   :verifier NoopHostnameVerifier/INSTANCE})
+  (delay {
+          :context (-> (SSLContexts/custom)
+                       (.loadTrustMaterial nil (reify TrustStrategy
+                                                 (isTrusted [_ _ _] true)))
+                       (.build))
+          :verifier NoopHostnameVerifier/INSTANCE}))
 
-(def ^SSLConnectionSocketFactory insecure-socket-factory
-  (let [{:keys [context  verifier]} insecure-context-verifier]
-    (SSLConnectionSocketFactory. ^SSLContext context
-                                 ^HostnameVerifier verifier)))
+(def ^:private insecure-socket-factory
+  (delay
+   (let [{:keys [context  verifier]} @insecure-context-verifier]
+     (SSLConnectionSocketFactory. ^SSLContext context
+                                  ^HostnameVerifier verifier))))
 
-(def ^SSLIOSessionStrategy insecure-strategy
-  (let [{:keys [context  verifier]} insecure-context-verifier]
-    (SSLIOSessionStrategy. ^SSLContext context ^HostnameVerifier verifier)))
+(def ^:private insecure-strategy
+  (delay
+   (let [{:keys [context  verifier]} @insecure-context-verifier]
+     (SSLIOSessionStrategy. ^SSLContext context ^HostnameVerifier verifier))))
 
-(def ^SSLConnectionSocketFactory secure-ssl-socket-factory
+(def ^:private ^SSLConnectionSocketFactory secure-ssl-socket-factory
   (SSLConnectionSocketFactory/getSocketFactory))
 
-(def ^SSLIOSessionStrategy secure-strategy
+(def ^:private ^SSLIOSessionStrategy secure-strategy
   (SSLIOSessionStrategy/getDefaultStrategy))
 
 (defn ^SSLConnectionSocketFactory SSLGenericSocketFactory
   "Given a function that returns a new socket, create an
   SSLConnectionSocketFactory that will use that socket."
-  ([socket-factory] (SSLGenericSocketFactory socket-factory (SSLContexts/createDefault)))
+  ([socket-factory]
+   (SSLGenericSocketFactory socket-factory nil))
   ([socket-factory ^SSLContext ssl-context]
-   (proxy [SSLConnectionSocketFactory] [ssl-context]
-     (connectSocket [timeout socket host remoteAddress localAddress context]
-       (let [^SSLConnectionSocketFactory this this] ;; avoid reflection
-         (proxy-super connectSocket timeout (socket-factory) host remoteAddress
-                      localAddress context))))))
+   (let [^SSLContext ssl-context' (or ssl-context (SSLContexts/createDefault))]
+     (proxy [SSLConnectionSocketFactory] [ssl-context']
+       (connectSocket [timeout socket host remoteAddress localAddress context]
+         (let [^SSLConnectionSocketFactory this this] ;; avoid reflection
+           (proxy-super connectSocket timeout (socket-factory) host remoteAddress
+                        localAddress context)))))))
 
 (defn ^PlainConnectionSocketFactory PlainGenericSocketFactory
   "Given a Function that returns a new socket, create a
@@ -105,74 +114,145 @@
                  NoopHostnameVerifier/INSTANCE
                  (DefaultHostnameVerifier.))}))
 
+(defn get-managers-context-verifier
+  "Given an instance or seqable data structure of TrustManager or KeyManager
+  will create and return an SSLContexts object including the resulting managers"
+  [{:keys [trust-managers key-managers]
+    :as req}]
+  (let [x-or-xs->x-array (fn [type x-or-xs]
+                           (cond
+                             (or (-> x-or-xs class .isArray)
+                                 (sequential? x-or-xs))
+                             (into-array type (seq x-or-xs))
+
+                             :else
+                             (into-array type [x-or-xs])))
+        trust-managers (when trust-managers
+                         (x-or-xs->x-array TrustManager trust-managers))
+        key-managers (when key-managers
+                       (x-or-xs->x-array KeyManager key-managers))]
+    {:context (doto (.build (SSLContexts/custom))
+                (.init key-managers trust-managers nil))
+     :verifier (if (opt req :insecure)
+                 NoopHostnameVerifier/INSTANCE
+                 (DefaultHostnameVerifier.))}))
+
 (defn make-socks-proxied-conn-manager
   "Given an optional hostname and a port, create a connection manager that's
   proxied using a SOCKS proxy."
-  ([^String hostname ^Integer port] (make-socks-proxied-conn-manager hostname port {}))
-  ([^String hostname ^Integer port {:keys [keystore keystore-type keystore-pass trust-store trust-store-type trust-store-pass] :as opts}]
+  ([^String hostname ^Integer port]
+   (make-socks-proxied-conn-manager hostname port {}))
+  ([^String hostname ^Integer port
+    {:keys [keystore keystore-type keystore-pass
+            trust-store trust-store-type trust-store-pass
+            trust-managers key-managers] :as opts}]
    (let [socket-factory #(socks-proxied-socket hostname port)
-         ssl-context (when (some (complement nil?) [keystore keystore-type keystore-pass trust-store trust-store-type trust-store-pass])
-                           (-> opts get-keystore-context-verifier :context))
+         ssl-context (cond
+                       (or trust-managers key-managers)
+                       (-> opts get-managers-context-verifier :context)
+
+                       (some (complement nil?)
+                             [keystore keystore-type keystore-pass trust-store
+                              trust-store-type trust-store-pass])
+                       (-> opts get-keystore-context-verifier :context))
          reg (-> (RegistryBuilder/create)
                  (.register "http" (PlainGenericSocketFactory socket-factory))
-                 (.register "https" (SSLGenericSocketFactory socket-factory ssl-context))
+                 (.register "https"
+                            (SSLGenericSocketFactory
+                             socket-factory ssl-context))
                  (.build))]
      (PoolingHttpClientConnectionManager. reg))))
 
-(def insecure-scheme-registry
-  (-> (RegistryBuilder/create)
-      (.register "http" PlainConnectionSocketFactory/INSTANCE)
-      (.register "https" insecure-socket-factory)
-      (.build)))
+(def ^:private insecure-scheme-registry
+  (delay
+   (-> (RegistryBuilder/create)
+       (.register "http" PlainConnectionSocketFactory/INSTANCE)
+       (.register "https" ^SSLConnectionSocketFactory @insecure-socket-factory)
+       (.build))))
 
-(def insecure-strategy-registry
-  (-> (RegistryBuilder/create)
-      (.register "http" NoopIOSessionStrategy/INSTANCE)
-      (.register "https" insecure-strategy)
-      (.build)))
+(def ^:private insecure-strategy-registry
+  (delay
+   (-> (RegistryBuilder/create)
+       (.register "http" NoopIOSessionStrategy/INSTANCE)
+       (.register "https" ^SSLIOSessionStrategy @insecure-strategy)
+       (.build))))
 
-(def regular-scheme-registry
+(def ^:private regular-scheme-registry
   (-> (RegistryBuilder/create)
       (.register "http" (PlainConnectionSocketFactory/getSocketFactory))
       (.register "https" secure-ssl-socket-factory)
       (.build)))
 
-(def regular-strategy-registry
+(def ^:private regular-strategy-registry
   (-> (RegistryBuilder/create)
       (.register "http" NoopIOSessionStrategy/INSTANCE)
       (.register "https" secure-strategy)
       (.build)))
 
-(defn ^Registry get-keystore-scheme-registry
-  [req]
-  (let [{:keys [context verifier]} (get-keystore-context-verifier req)
-        factory (SSLConnectionSocketFactory. ^SSLContext context
+(defn ^Registry get-custom-scheme-registry
+  [{:keys [context verifier]}]
+  (let [factory (SSLConnectionSocketFactory. ^SSLContext context
                                              ^HostnameVerifier verifier)]
     (-> (RegistryBuilder/create)
         (.register "http" (PlainConnectionSocketFactory/getSocketFactory))
         (.register "https" factory)
         (.build))))
 
-(defn ^Registry get-keystore-strategy-registry
-  [req]
-  (let [{:keys [context verifier]} (get-keystore-context-verifier req)
-        strategy (SSLIOSessionStrategy. ^SSLContext context
+(defn ^Registry get-custom-strategy-registry
+  [{:keys [context verifier]}]
+  (let [strategy (SSLIOSessionStrategy. ^SSLContext context
                                         ^HostnameVerifier verifier)]
     (-> (RegistryBuilder/create)
         (.register "http" NoopIOSessionStrategy/INSTANCE)
         (.register "https" strategy)
         (.build))))
 
+(defn ^Registry get-keystore-scheme-registry
+  [req]
+  (-> req
+      get-keystore-context-verifier
+      get-custom-scheme-registry))
+
+(defn ^Registry get-keystore-strategy-registry
+  [req]
+  (-> req
+      get-keystore-context-verifier
+      get-custom-strategy-registry))
+
+(defn ^Registry get-managers-scheme-registry
+  [req]
+  (-> req
+      get-managers-context-verifier
+      get-custom-scheme-registry))
+
+(defn ^Registry get-managers-strategy-registry
+  [req]
+  (-> req
+      get-managers-context-verifier
+      get-custom-strategy-registry))
+
 (defn ^BasicHttpClientConnectionManager make-regular-conn-manager
-  [{:keys [keystore trust-store] :as req}]
-  (cond
-    (or keystore trust-store)
-    (BasicHttpClientConnectionManager. (get-keystore-scheme-registry req))
+  [{:keys [keystore trust-store
+           key-managers trust-managers
+           socket-timeout] :as req}]
+  (let [conn-manager (cond
+                       (or key-managers trust-managers)
+                       (BasicHttpClientConnectionManager. (get-managers-scheme-registry req))
 
-    (opt req :insecure) (BasicHttpClientConnectionManager.
-                         insecure-scheme-registry)
+                       (or keystore trust-store)
+                       (BasicHttpClientConnectionManager. (get-keystore-scheme-registry req))
 
-    :else (BasicHttpClientConnectionManager. regular-scheme-registry)))
+                       (opt req :insecure) (BasicHttpClientConnectionManager.
+                                            @insecure-scheme-registry)
+
+                       :else (BasicHttpClientConnectionManager. regular-scheme-registry))]
+    (when socket-timeout
+      (.setSocketConfig conn-manager
+                        (-> (.getSocketConfig conn-manager)
+                            (SocketConfig/copy)
+                            (.setSoTimeout socket-timeout) ;modify only the socket-timeout
+                            (.build))))
+    conn-manager))
 
 (defn- ^DefaultConnectingIOReactor make-ioreactor
   [{:keys [connect-timeout interest-op-queued io-thread-count rcv-buf-size
@@ -194,13 +274,17 @@
 
 (defn ^PoolingNHttpClientConnectionManager
   make-regular-async-conn-manager
-  [{:keys [keystore trust-store] :as req}]
+  [{:keys [keystore trust-store
+           key-managers trust-managers] :as req}]
   (let [^Registry registry (cond
+                             (or key-managers trust-managers)
+                             (get-managers-strategy-registry req)
+
                              (or keystore trust-store)
                              (get-keystore-strategy-registry req)
 
                              (opt req :insecure)
-                             insecure-strategy-registry
+                             @insecure-strategy-registry
 
                              :else regular-strategy-registry)
         io-reactor (make-ioreactor {:shutdown-grace-period 1})]
@@ -216,9 +300,14 @@
   "Given an timeout and optional insecure? flag, create a
   PoolingHttpClientConnectionManager with <timeout> seconds set as the
   timeout value."
-  [{:keys [timeout keystore trust-store] :as config}]
+  [{:keys [timeout
+           keystore trust-store
+           key-managers trust-managers] :as config}]
   (let [registry (cond
-                   (opt config :insecure) insecure-scheme-registry
+                   (opt config :insecure) @insecure-scheme-registry
+
+                   (or key-managers trust-managers)
+                   (get-managers-scheme-registry config)
 
                    (or keystore trust-store)
                    (get-keystore-scheme-registry config)
@@ -250,7 +339,13 @@
   :trust-store - trust store file to be used for connection manager
   :trust-store-pass - trust store password
 
-  Note that :insecure? and :keystore/:trust-store options are mutually exclusive
+  :key-managers - KeyManager objects to be used for connection manager
+  :trust-managers - TrustManager objects to be used for connection manager
+
+  Note that :insecure? and :keystore/:trust-store/:key-managers/:trust-managers options are mutually exclusive
+
+  Note that :key-managers/:trust-managers have precedence over :keystore/:trust-store options
+
 
   If the value 'nil' is specified or the value is not set, the default value
   will be used."
@@ -269,19 +364,28 @@
     conn-man))
 
 (defn- ^PoolingNHttpClientConnectionManager make-reusable-async-conn-manager*
-  [{:keys [timeout keystore trust-store io-config] :as config}]
+  [{:keys [timeout keystore trust-store io-config
+           key-managers trust-managers] :as config}]
   (let [registry (cond
-                   (opt config :insecure) insecure-strategy-registry
+                   (opt config :insecure) @insecure-strategy-registry
+
+                   (or key-managers trust-managers)
+                   (get-managers-scheme-registry config)
 
                    (or keystore trust-store)
                    (get-keystore-scheme-registry config)
 
-                   :else regular-strategy-registry)]
+                   :else regular-strategy-registry)
+        io-reactor (make-ioreactor io-config)
+        protocol-handler (HttpAsyncRequestExecutor.)
+        io-event-dispatch (DefaultHttpClientIODispatch. protocol-handler
+                                                        ConnectionConfig/DEFAULT)]
+    (future (.execute io-reactor io-event-dispatch))
     (proxy [PoolingNHttpClientConnectionManager ReuseableAsyncConnectionManager]
-        [(make-ioreactor io-config) nil registry nil nil timeout
+        [io-reactor nil registry nil nil timeout
          java.util.concurrent.TimeUnit/SECONDS])))
 
-(defn ^PoolingNHttpClientConnectionManager make-reuseable-async-conn-manager
+(defn ^PoolingNHttpClientConnectionManager make-reusable-async-conn-manager
   "Creates a default pooling async connection manager with the specified
   options. Handles the same options as make-reusable-conn-manager plus
   :io-config which should be a map containing some of the following keys:
@@ -325,6 +429,11 @@
       (.setDefaultMaxPerRoute conn-man default-per-route))
     conn-man))
 
+(defn ^PoolingNHttpClientConnectionManager make-reuseable-async-conn-manager
+  "Wraps correctly-spelled version - keeping for backwards compatibility."
+  [opts]
+  (make-reusable-async-conn-manager opts))
+
 (defmulti shutdown-manager
   "Shut down the given connection manager, if it is not nil"
   class)
