@@ -1,15 +1,14 @@
 (ns riemann.core
   "Binds together an index, servers, and streams."
-  (:use [riemann.time :only [unix-time]]
-        [riemann.common :only [deprecated localhost event]]
-        clojure.tools.logging
-        [riemann.instrumentation :only [Instrumented]])
-  (:require riemann.streams
+  (:require [riemann.time :refer [unix-time]]
+            [riemann.common :refer [deprecated localhost event]]
+            riemann.streams
             [riemann.service :as service :refer [Service ServiceEquiv]]
             [riemann.index :as index :refer [Index]]
             [riemann.pubsub :as ps]
             [riemann.test :as test]
-            [riemann.instrumentation :as instrumentation]
+            [riemann.instrumentation :as instrumentation :refer [Instrumented]]
+            [clojure.tools.logging :refer [warn info]]
             clojure.set))
 
 (defn stream!
@@ -285,6 +284,7 @@
              event in the expired event. Defaults to [:host :service], which
              means that when an event expires, its :host and :service are
              copied to a new event, but no other keys are preserved.
+             If :keep-keys is :all, all event keys will be preserved.
              The state of an expired event is always \"expired\", and its time
              is always the time that the event expired."
   ([] (reaper 10))
@@ -297,7 +297,8 @@
          (when-let [i (:index core)]
            (doseq [state (index/expire i)]
              (try
-               (let [e (-> (select-keys state keep-keys)
+               (let [filtered-state (if (= keep-keys :all) state (select-keys state keep-keys))
+                     e (-> filtered-state
                          (merge {:state "expired"
                                  :time (unix-time)}))]
                  (when-let [registry (:pubsub core)]
