@@ -5,8 +5,7 @@
              Level
              Logger)
            (ch.qos.logback.core
-             ConsoleAppender
-             FileAppender)
+             ConsoleAppender)
            (ch.qos.logback.core.util
              FileSize)
            (ch.qos.logback.core.encoder
@@ -41,25 +40,25 @@
 (defmulti encoder identity)
 
 (defmethod encoder :json
-  [type]
+  [_]
   (LogstashEncoder.))
 
 (defmethod encoder :json-event
-  [type]
+  [_]
   (encoder :json-event-v0))
 
 (defmethod encoder :json-event-v0
-  [type]
+  [_]
   (doto (LayoutWrappingEncoder.)
     (.setLayout (JSONEventLayoutV0.))))
 
 (defmethod encoder :json-event-v1
-  [type]
+  [_]
   (doto (LayoutWrappingEncoder.)
     (.setLayout (JSONEventLayoutV1.))))
 
 (defmethod encoder :riemann
-  [type]
+  [_]
   (doto (PatternLayoutEncoder.)
     (.setPattern "%p [%d] %t - %c - %m%n%throwable")))
 
@@ -185,22 +184,23 @@
   "Initialize logging. You will probably call this from the config file. You can
   call init more than once; its changes are destructive. Options:
 
-  :console?         Determine if logging should happen on the console.
-  :console-layout   Specifying console layout.
-  :file             The file to log to. If omitted, log to console only.
-  :file-layout      Specifying file layout.
-  :files            A list of files to log to. If provided, a seq or vector is
-                    expected containing maps with a :file and an :file-layout
-  :logsize-rotate   If size (in bytes) is specified use size based rotation
-                    otherwise use default time based rotation.
-  :rotate-count     Specifying the number of rotated files to keep. If omitted,
-                    keep last 10 rotated files.
+  - :console?         Determine if logging should happen on the console.
+  - :console-layout   Specifying console layout.
+  - :file             The file to log to. If omitted, log to console only.
+  - :file-layout      Specifying file layout.
+  - :files            A list of files to log to. If provided, a seq or vector is
+                      expected containing maps with a :file and an :file-layout
+  - :logsize-rotate   If size (in bytes) is specified use size based rotation
+                      otherwise use default time based rotation.
+  - :rotate-count     Specifying the number of rotated files to keep. If omitted,
+                      keep last 10 rotated files.
 
   Layout can be :riemann or :json. If layout is omitted, the default layout
   :riemann will be used.
 
   For example:
 
+  ```clojure
       ; Basic console logging
       (init)
 
@@ -220,7 +220,8 @@
              :files [{:file \"/var/log/riemann.log\"},
                      {:file \"/var/log/riemann.json.log\" :file-layout :json}]
              :logsize-rotate 100
-             :rotate-count 5})"
+             :rotate-count 5})
+  ```"
   ([] (init {}))
   ([opts]
     (let [logger   (get-logger)
