@@ -5,7 +5,7 @@
             [interval-metrics.core    :as metrics]
             [org.httpkit.server       :as http]
             [riemann.common           :as common]
-            [riemann.test              :as test]
+            [riemann.test             :as test]
             [riemann.pubsub           :refer [subscribe! unsubscribe!]]
             [riemann.instrumentation  :refer [Instrumented]]
             [riemann.service          :refer [Service ServiceEquiv]]
@@ -38,7 +38,7 @@
   "Yield a function that given an incoming event will
    test for a given predicate and when it matches will
    format it for sending it over a SSE channel."
-  [{:keys [out] :as stats} ch pred]
+  [_ ch pred]
   (fn [event]
     ;; Send event to client, measuring write latency
     (when (pred event)
@@ -71,7 +71,7 @@
 
             (http/on-close
              ch
-             (fn [status]
+             (fn [_]
                (info "Closing SSE channel " remote-addr query)
                (unsubscribe! pubsub sub)))))
         (sse-error-uri ch uri)))))
@@ -142,13 +142,14 @@
   "Creates a new SSE server for a core.
 
   Options:
-  :host    The address to listen on (default 127.0.0.1)
-  :port    The port to listen on (default 5558)
-  :headers Additional headers to send with the reply. By default
-           Content-Type is set to text/event-stream and Cache-Control to
-           no-cache. If you do not expose your client web application behind
-           the same host, you will probably need to add an
-           Access-Control-Allow-Origin header here"
+
+  - :host    The address to listen on (default 127.0.0.1)
+  - :port    The port to listen on (default 5558)
+  - :headers Additional headers to send with the reply. By default
+             Content-Type is set to text/event-stream and Cache-Control to
+             no-cache. If you do not expose your client web application behind
+             the same host, you will probably need to add an
+             Access-Control-Allow-Origin header here"
   ([] (sse-server {}))
   ([{:keys [host port headers]
      :or   {host    "127.0.0.1"
